==> jec-wildcat-1.0.0.tgz: package/src/com/onsoft/wildcat/builders/WildcatBuilder.ts <==
//  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
//
//   Copyright 2016-2017 Pascal ECHEMANN.
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

import {Wildcat} from "../Wildcat";
import {DefaultWildcatProcessor} from "../core/DefaultWildcatProcessor";

/**
 * A helper class that creates and returns new <code>Wildcat</code> instances.
 */
export class WildcatBuilder {

  //////////////////////////////////////////////////////////////////////////////
  // Constructor function
  //////////////////////////////////////////////////////////////////////////////

  /**
   * Creates a new <code>WildcatBuilder</code> instance.
   */
  constructor() {}

  //////////////////////////////////////////////////////////////////////////////
  // Public methods
  //////////////////////////////////////////////////////////////////////////////

  /**
   * Creates and returns new <code>Wildcat</code> instances.
   * 
   * @return {Wildcat} a new <code>Wildcat</code> instance.
   */
  public build():Wildcat {
    let wildcat:Wildcat = new DefaultWildcatProcessor();
    return wildcat;
  }
};

==> jec-wildcat-1.0.9.tgz: package/src/com/onsoft/wildcat/builders/WildcatBuilder.ts <==
//  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
//
//   Copyright 2016-2018 Pascal ECHEMANN.
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

import {Wildcat} from "../Wildcat";
import {DefaultWildcatProcessor} from "../core/DefaultWildcatProcessor";

/**
 * A helper class that creates and returns new <code>Wildcat</code> instances.
 */
export class WildcatBuilder {

  //////////////////////////////////////////////////////////////////////////////
  // Constructor function
  //////////////////////////////////////////////////////////////////////////////

  /**
   * Creates a new <code>WildcatBuilder</code> instance.
   */
  constructor() {}

  //////////////////////////////////////////////////////////////////////////////
  // Public methods
  //////////////////////////////////////////////////////////////////////////////

  /**
   * Creates and returns new <code>Wildcat</code> instances.
   * 
   * @return {Wildcat} a new <code>Wildcat</code> instance.
   */
  public build():Wildcat {
    const wildcat:Wildcat = new DefaultWildcatProcessor();
    return wildcat;
  }
};
